@@ -147,7 +147,7 @@ start_service(SvcName, Opts)
 
 start_rc({ok = T, _Pid}) ->
     T;
-start_rc({error, _} = No) ->
+start_rc({error, _R} = No) ->
     No;
 start_rc(timeout) ->
     {error, application_not_started}.
@@ -912,6 +912,7 @@ init_app({application, Opts} = T) ->
     M = get_opt(call_mutates_state, Opts, false, [true]),
     A = get_opt(answer_errors, Opts, discard, [callback, report]),
     P = get_opt(request_errors, Opts, answer_3xxx, [answer, callback]),
+
     #diameter_app{alias = Alias,
                   dictionary = Dict,
                   id = cb(Dict, id),
